@@ -1,13 +1,14 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
 from __future__ import annotations
 
-from astroid import context, inference_tip, nodes
+from astroid import context, nodes
 from astroid.brain.helpers import register_module_extender
 from astroid.builder import _extract_single_node, parse
-from astroid.const import PY39_PLUS, PY311_PLUS
+from astroid.const import PY311_PLUS
+from astroid.inference_tip import inference_tip
 from astroid.manager import AstroidManager
 
 
@@ -19,8 +20,7 @@ def _re_transform() -> nodes.Module:
         import_compiler = "import re._compiler as _compiler"
     else:
         import_compiler = "import sre_compile as _compiler"
-    return parse(
-        f"""
+    return parse(f"""
     {import_compiler}
     NOFLAG = 0
     ASCII = _compiler.SRE_FLAG_ASCII
@@ -40,11 +40,7 @@ def _re_transform() -> nodes.Module:
     S = DOTALL
     X = VERBOSE
     T = TEMPLATE
-    """
-    )
-
-
-register_module_extender(AstroidManager(), "re", _re_transform)
+    """)
 
 
 CLASS_GETITEM_TEMPLATE = """
@@ -84,13 +80,16 @@ def infer_pattern_match(node: nodes.Call, ctx: context.InferenceContext | None =
         lineno=node.lineno,
         col_offset=node.col_offset,
         parent=node.parent,
+        end_lineno=node.end_lineno,
+        end_col_offset=node.end_col_offset,
     )
-    if PY39_PLUS:
-        func_to_add = _extract_single_node(CLASS_GETITEM_TEMPLATE)
-        class_def.locals["__class_getitem__"] = [func_to_add]
+    func_to_add = _extract_single_node(CLASS_GETITEM_TEMPLATE)
+    class_def.locals["__class_getitem__"] = [func_to_add]
     return iter([class_def])
 
 
-AstroidManager().register_transform(
-    nodes.Call, inference_tip(infer_pattern_match), _looks_like_pattern_or_match
-)
+def register(manager: AstroidManager) -> None:
+    register_module_extender(manager, "re", _re_transform)
+    manager.register_transform(
+        nodes.Call, inference_tip(infer_pattern_match), _looks_like_pattern_or_match
+    )
